@@ -37,22 +37,22 @@
 #define		BZRTP_PARSER_ERROR_OUTOFORDER			0xa004
 #define		BZRTP_PARSER_ERROR_INVALIDMESSAGE		0xa008
 #define		BZRTP_PARSER_ERROR_INVALIDCONTEXT		0xa010
-#define		BZRTP_PARSER_ERROR_UNMATCHINGCONFIRMMAC	0xa020
+#define		BZRTP_PARSER_ERROR_UNMATCHINGCONFIRMMAC		0xa020
 #define		BZRTP_PARSER_ERROR_UNMATCHINGSSRC		0xa040
-#define		BZRTP_PARSER_ERROR_UNMATCHINGHASHCHAIN	0xa080
+#define		BZRTP_PARSER_ERROR_UNMATCHINGHASHCHAIN		0xa080
 #define		BZRTP_PARSER_ERROR_UNMATCHINGMAC		0xa100
-#define		BZRTP_PARSER_ERROR_UNEXPECTEDMESSAGE	0xa200
+#define		BZRTP_PARSER_ERROR_UNEXPECTEDMESSAGE		0xa200
 #define		BZRTP_PARSER_ERROR_UNMATCHINGHVI		0xa400
 
 #define		BZRTP_BUILDER_ERROR_INVALIDPACKET		0x5001
 #define		BZRTP_BUILDER_ERROR_INVALIDMESSAGE		0x5002
-#define		BZRTP_BUILDER_ERROR_INVALIDMESSAGETYPE	0x5004
-#define		BZRTP_BUILDER_ERROR_UNKNOWN				0x5008
+#define		BZRTP_BUILDER_ERROR_INVALIDMESSAGETYPE		0x5004
+#define		BZRTP_BUILDER_ERROR_UNKNOWN			0x5008
 #define		BZRTP_BUILDER_ERROR_INVALIDCONTEXT		0x5010
 
-#define		BZRTP_CREATE_ERROR_INVALIDMESSAGETYPE			0x0a01
+#define		BZRTP_CREATE_ERROR_INVALIDMESSAGETYPE		0x0a01
 #define		BZRTP_CREATE_ERROR_UNABLETOCREATECRYPTOCONTEXT	0x0a02
-#define		BZRTP_CREATE_ERROR_INVALIDCONTEXT				0x0a04
+#define		BZRTP_CREATE_ERROR_INVALIDCONTEXT		0x0a04
 
 /* map all message type to an uint8_t value */
 #define		MSGTYPE_INVALID		0x00
@@ -96,7 +96,7 @@ typedef struct bzrtpPacket_struct {
  */
 typedef struct bzrtpHelloMessage_struct {
 	uint8_t version[4]; /**< a string defining the current version, shall be 1.10 */
-	uint8_t clientIdentifier[16]; /**< a string identifing the vendor and release of ZRTP software */
+	uint8_t clientIdentifier[17]; /**< a string identifing the vendor and release of ZRTP software, actual content is 16, but last character forced to '\0' */
 	uint8_t H3[32]; /**< the hash image H3 (256 bits) */
 	uint8_t ZID[12]; /**< unique identifier for ZRTP endpoint (96 bits) */
 	uint8_t	S; /**< The signature-capable flag. If signatures are not supported, the (S) flag MUST be set to zero (1 bit) */
@@ -277,7 +277,7 @@ typedef struct bzrtpPingAckMessage_struct {
  *
  * @return		The create bzrtpPacket structure(to be freed using bzrtp_freeZrtpPacket). NULL on error
  */
-bzrtpPacket_t *bzrtp_packetCheck(const uint8_t * input, uint16_t inputLength, uint16_t lastValidSequenceNumber, int *exitCode);
+BZRTP_EXPORT bzrtpPacket_t *bzrtp_packetCheck(const uint8_t * input, uint16_t inputLength, uint16_t lastValidSequenceNumber, int *exitCode);
 
 
 /**
@@ -291,7 +291,7 @@ bzrtpPacket_t *bzrtp_packetCheck(const uint8_t * input, uint16_t inputLength, ui
  *
  * @return 	0 on sucess, error code otherwise
  */
-int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpChannelContext, const uint8_t * input, uint16_t inputLength, bzrtpPacket_t *zrtpPacket); 
+BZRTP_EXPORT int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpChannelContext, const uint8_t * input, uint16_t inputLength, bzrtpPacket_t *zrtpPacket); 
 
 
 /**
@@ -304,7 +304,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
  *
  * @return		An empty packet initialised to get data for the requested paquet tyep. NULL on error
  */ 
-bzrtpPacket_t *bzrtp_createZrtpPacket(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpChannelContext, uint32_t messageType, int *exitCode);
+BZRTP_EXPORT bzrtpPacket_t *bzrtp_createZrtpPacket(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpChannelContext, uint32_t messageType, int *exitCode);
 
 
 /**
@@ -319,7 +319,7 @@ bzrtpPacket_t *bzrtp_createZrtpPacket(bzrtpContext_t *zrtpContext, bzrtpChannelC
  * @return			0 on success, error code otherwise
  *
  */
-int bzrtp_packetBuild(bzrtpContext_t *zrtpContext,  bzrtpChannelContext_t *zrtpChannelContext, bzrtpPacket_t *zrtpPacket, uint16_t sequenceNumber);
+BZRTP_EXPORT int bzrtp_packetBuild(bzrtpContext_t *zrtpContext,  bzrtpChannelContext_t *zrtpChannelContext, bzrtpPacket_t *zrtpPacket, uint16_t sequenceNumber);
 
 
 /**
@@ -328,7 +328,7 @@ int bzrtp_packetBuild(bzrtpContext_t *zrtpContext,  bzrtpChannelContext_t *zrtpC
  * @param[in] zrtpPacket	The packet to be freed
  *
  */
-void bzrtp_freeZrtpPacket(bzrtpPacket_t *zrtpPacket);
+BZRTP_EXPORT void bzrtp_freeZrtpPacket(bzrtpPacket_t *zrtpPacket);
 
 /**
  * @brief Modify the current sequence number of the packet in the packetString and sequenceNumber fields
@@ -340,5 +340,5 @@ void bzrtp_freeZrtpPacket(bzrtpPacket_t *zrtpPacket);
  * 
  * return		0 on succes, error code otherwise
  */
-int bzrtp_packetUpdateSequenceNumber(bzrtpPacket_t *zrtpPacket, uint16_t sequenceNumber);
+BZRTP_EXPORT int bzrtp_packetUpdateSequenceNumber(bzrtpPacket_t *zrtpPacket, uint16_t sequenceNumber);
 #endif /* PACKETPARSER_H */
