@@ -232,6 +232,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 				memcpy(messageData->version, messageContent, 4);
 				messageContent +=4;
 				memcpy(messageData->clientIdentifier, messageContent, 16);
+				messageData->clientIdentifier[16] = '\0'; /* be sure the clientIdentifier is a NULL terminated string */
 				messageContent +=16;
 				memcpy(messageData->H3, messageContent, 32);
 				messageContent +=32;
@@ -258,31 +259,31 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 
 				/* parse the variable length part: algorithms types */
 				for (i=0; i<messageData->hc; i++) {
-					messageData->supportedHash[i] = cryptoAlgoTypeStringToInt(messageContent, ZRTP_HASH_TYPE);
+					messageData->supportedHash[i] = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_HASH_TYPE);
 					messageContent +=4;
 				}
 				for (i=0; i<messageData->cc; i++) {
-					messageData->supportedCipher[i] = cryptoAlgoTypeStringToInt(messageContent, ZRTP_CIPHERBLOCK_TYPE);
+					messageData->supportedCipher[i] = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_CIPHERBLOCK_TYPE);
 					messageContent +=4;
 				}
 				for (i=0; i<messageData->ac; i++) {
-					messageData->supportedAuthTag[i] = cryptoAlgoTypeStringToInt(messageContent, ZRTP_AUTHTAG_TYPE);
+					messageData->supportedAuthTag[i] = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_AUTHTAG_TYPE);
 					messageContent +=4;
 				}
 				for (i=0; i<messageData->kc; i++) {
-					messageData->supportedKeyAgreement[i] = cryptoAlgoTypeStringToInt(messageContent, ZRTP_KEYAGREEMENT_TYPE);
+					messageData->supportedKeyAgreement[i] = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_KEYAGREEMENT_TYPE);
 					messageContent +=4;
 				}
 				for (i=0; i<messageData->sc; i++) {
-					messageData->supportedSas[i] = cryptoAlgoTypeStringToInt(messageContent, ZRTP_SAS_TYPE);
+					messageData->supportedSas[i] = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_SAS_TYPE);
 					messageContent +=4;
 				}
 
-				addMandatoryCryptoTypesIfNeeded(ZRTP_HASH_TYPE, messageData->supportedHash, &messageData->hc);
-				addMandatoryCryptoTypesIfNeeded(ZRTP_CIPHERBLOCK_TYPE, messageData->supportedCipher, &messageData->cc);
-				addMandatoryCryptoTypesIfNeeded(ZRTP_AUTHTAG_TYPE, messageData->supportedAuthTag, &messageData->ac);
-				addMandatoryCryptoTypesIfNeeded(ZRTP_KEYAGREEMENT_TYPE, messageData->supportedKeyAgreement, &messageData->kc);
-				addMandatoryCryptoTypesIfNeeded(ZRTP_SAS_TYPE, messageData->supportedSas, &messageData->sc);
+				bzrtp_addMandatoryCryptoTypesIfNeeded(ZRTP_HASH_TYPE, messageData->supportedHash, &messageData->hc);
+				bzrtp_addMandatoryCryptoTypesIfNeeded(ZRTP_CIPHERBLOCK_TYPE, messageData->supportedCipher, &messageData->cc);
+				bzrtp_addMandatoryCryptoTypesIfNeeded(ZRTP_AUTHTAG_TYPE, messageData->supportedAuthTag, &messageData->ac);
+				bzrtp_addMandatoryCryptoTypesIfNeeded(ZRTP_KEYAGREEMENT_TYPE, messageData->supportedKeyAgreement, &messageData->kc);
+				bzrtp_addMandatoryCryptoTypesIfNeeded(ZRTP_SAS_TYPE, messageData->supportedSas, &messageData->sc);
 
 				memcpy(messageData->MAC, messageContent, 8);
 				
@@ -344,13 +345,13 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 
 				memcpy(messageData->ZID, messageContent, 12);
 				messageContent +=12;
-				messageData->hashAlgo = cryptoAlgoTypeStringToInt(messageContent, ZRTP_HASH_TYPE);
+				messageData->hashAlgo = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_HASH_TYPE);
 				messageContent += 4;
-				messageData->cipherAlgo = cryptoAlgoTypeStringToInt(messageContent, ZRTP_CIPHERBLOCK_TYPE);
+				messageData->cipherAlgo = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_CIPHERBLOCK_TYPE);
 				messageContent += 4;
-				messageData->authTagAlgo = cryptoAlgoTypeStringToInt(messageContent, ZRTP_AUTHTAG_TYPE);
+				messageData->authTagAlgo = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_AUTHTAG_TYPE);
 				messageContent += 4;
-				messageData->keyAgreementAlgo = cryptoAlgoTypeStringToInt(messageContent, ZRTP_KEYAGREEMENT_TYPE);
+				messageData->keyAgreementAlgo = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_KEYAGREEMENT_TYPE);
 				messageContent += 4;
 				/* commit message length depends on the key agreement type choosen (and set in the zrtpContext->keyAgreementAlgo) */
 				switch(messageData->keyAgreementAlgo) {
@@ -376,7 +377,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 					free(messageData);
 					return BZRTP_PARSER_ERROR_INVALIDMESSAGE;
 				}
-				messageData->sasAlgo = cryptoAlgoTypeStringToInt(messageContent, ZRTP_SAS_TYPE);
+				messageData->sasAlgo = bzrtp_cryptoAlgoTypeStringToInt(messageContent, ZRTP_SAS_TYPE);
 				messageContent += 4;
 
 				/* if it is a multistream or preshared commit, get the 16 bytes nonce */
@@ -427,7 +428,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 				messageContent +=32;
 
 				/* We have now H1, check it matches the H2 we had in the commit message H2=SHA256(H1) and that the Commit message MAC is correct */
-				if ( zrtpChannelContext->role == RESPONDER) { /* do it only if we are responder (we received a commit packet) */
+				if ( zrtpChannelContext->role == BZRTP_ROLE_RESPONDER) { /* do it only if we are responder (we received a commit packet) */
 					uint8_t checkH2[32];
 					uint8_t checkMAC[32];
 					bzrtpCommitMessage_t *peerCommitMessageData;
@@ -538,7 +539,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 				uint8_t *confirmPlainMessage;
 
 				/* we shall first decrypt and validate the message, check we have the keys to do it */
-				if (zrtpChannelContext->role == RESPONDER) { /* responder uses initiator's keys to decrypt */
+				if (zrtpChannelContext->role == BZRTP_ROLE_RESPONDER) { /* responder uses initiator's keys to decrypt */
 					if ((zrtpChannelContext->zrtpkeyi == NULL) || (zrtpChannelContext->mackeyi == NULL)) {
 						return BZRTP_PARSER_ERROR_INVALIDCONTEXT;
 					}
@@ -546,7 +547,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 					confirmMessageMacKey = zrtpChannelContext->mackeyi;
 				}
 
-				if (zrtpChannelContext->role == INITIATOR) { /* the iniator uses responder's keys to decrypt */
+				if (zrtpChannelContext->role == BZRTP_ROLE_INITIATOR) { /* the iniator uses responder's keys to decrypt */
 					if ((zrtpChannelContext->zrtpkeyr == NULL) || (zrtpChannelContext->mackeyr == NULL)) {
 						return BZRTP_PARSER_ERROR_INVALIDCONTEXT;
 					}
@@ -592,7 +593,7 @@ int bzrtp_packetParser(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpC
 					bctbx_sha256(messageData->H0, 32, 32, checkH1);
 
 					/* if we are responder, we received a commit packet with H2 then check that H2=SHA256(H1) and that the commit message MAC keyed with H1 match */
-					if ( zrtpChannelContext->role == RESPONDER) {
+					if ( zrtpChannelContext->role == BZRTP_ROLE_RESPONDER) {
 						uint8_t checkH2[32];
 						uint8_t checkMAC[32];
 						bzrtpCommitMessage_t *peerCommitMessageData;
@@ -793,23 +794,23 @@ int bzrtp_packetBuild(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpCh
 
 				/* now set optionnal supported algorithms */
 				for (i=0; i<messageData->hc; i++) {
-					cryptoAlgoTypeIntToString(messageData->supportedHash[i], messageString);
+					bzrtp_cryptoAlgoTypeIntToString(messageData->supportedHash[i], messageString);
 					messageString +=4;
 				}
 				for (i=0; i<messageData->cc; i++) {
-					cryptoAlgoTypeIntToString(messageData->supportedCipher[i], messageString);
+					bzrtp_cryptoAlgoTypeIntToString(messageData->supportedCipher[i], messageString);
 					messageString +=4;
 				}
 				for (i=0; i<messageData->ac; i++) {
-					cryptoAlgoTypeIntToString(messageData->supportedAuthTag[i], messageString);
+					bzrtp_cryptoAlgoTypeIntToString(messageData->supportedAuthTag[i], messageString);
 					messageString +=4;
 				}
 				for (i=0; i<messageData->kc; i++) {
-					cryptoAlgoTypeIntToString(messageData->supportedKeyAgreement[i], messageString);
+					bzrtp_cryptoAlgoTypeIntToString(messageData->supportedKeyAgreement[i], messageString);
 					messageString +=4;
 				}
 				for (i=0; i<messageData->sc; i++) {
-					cryptoAlgoTypeIntToString(messageData->supportedSas[i], messageString);
+					bzrtp_cryptoAlgoTypeIntToString(messageData->supportedSas[i], messageString);
 					messageString +=4;
 				}
 
@@ -873,15 +874,15 @@ int bzrtp_packetBuild(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpCh
 				messageString += 32;
 				memcpy(messageString, messageData->ZID, 12);
 				messageString += 12;
-				cryptoAlgoTypeIntToString(messageData->hashAlgo, messageString);
+				bzrtp_cryptoAlgoTypeIntToString(messageData->hashAlgo, messageString);
 				messageString += 4;
-				cryptoAlgoTypeIntToString(messageData->cipherAlgo, messageString);
+				bzrtp_cryptoAlgoTypeIntToString(messageData->cipherAlgo, messageString);
 				messageString += 4;
-				cryptoAlgoTypeIntToString(messageData->authTagAlgo, messageString);
+				bzrtp_cryptoAlgoTypeIntToString(messageData->authTagAlgo, messageString);
 				messageString += 4;
-				cryptoAlgoTypeIntToString(messageData->keyAgreementAlgo, messageString);
+				bzrtp_cryptoAlgoTypeIntToString(messageData->keyAgreementAlgo, messageString);
 				messageString += 4;
-				cryptoAlgoTypeIntToString(messageData->sasAlgo, messageString);
+				bzrtp_cryptoAlgoTypeIntToString(messageData->sasAlgo, messageString);
 				messageString += 4;
 
 				/* if it is a multistream or preshared commit insert the 16 bytes nonce */
@@ -962,7 +963,7 @@ int bzrtp_packetBuild(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpCh
 				uint16_t plainMessageStringIndex = 0;
 
 				/* we will have to encrypt and validate the message, check we have the keys to do it */
-				if (zrtpChannelContext->role == INITIATOR) {
+				if (zrtpChannelContext->role == BZRTP_ROLE_INITIATOR) {
 					if ((zrtpChannelContext->zrtpkeyi == NULL) || (zrtpChannelContext->mackeyi == NULL)) {
 						return BZRTP_BUILDER_ERROR_INVALIDCONTEXT;
 					}
@@ -970,7 +971,7 @@ int bzrtp_packetBuild(bzrtpContext_t *zrtpContext, bzrtpChannelContext_t *zrtpCh
 					confirmMessageMacKey = zrtpChannelContext->mackeyi;
 				}
 
-				if (zrtpChannelContext->role == RESPONDER) {
+				if (zrtpChannelContext->role == BZRTP_ROLE_RESPONDER) {
 					if ((zrtpChannelContext->zrtpkeyr == NULL) || (zrtpChannelContext->mackeyr == NULL)) {
 						return BZRTP_BUILDER_ERROR_INVALIDCONTEXT;
 					}
@@ -1135,6 +1136,7 @@ bzrtpPacket_t *bzrtp_createZrtpPacket(bzrtpContext_t *zrtpContext, bzrtpChannelC
 				/* initialise some fields using zrtp context data */
 				memcpy(zrtpHelloMessage->version, ZRTP_VERSION, 4);
 				strncpy((char*)zrtpHelloMessage->clientIdentifier, ZRTP_CLIENT_IDENTIFIER, 16);
+				zrtpHelloMessage->clientIdentifier[16]='\0'; /* be sure the clientIdentifier filed is a NULL terminated string */
 				memcpy(zrtpHelloMessage->H3, zrtpChannelContext->selfH[3], 32);
 				memcpy(zrtpHelloMessage->ZID, zrtpContext->selfZID, 12);
 				/* set all S,M,P flags to zero as we're not able to verify signatures, we're not a PBX(TODO: implement?), we're not passive */
